{
=============================================================================
| THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  |
| AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    |
| IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   |
| ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR  |
| ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL       |
| DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR   |
| SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER   |
| CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT           |
| LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY    |
| OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH  |
| DAMAGE.                                                                      |
=============================================================================
   Author:  D.J.C. Blijker.
   Date:    23-4-2003
   version: 1.0
   e-mail:  c.blijker@wxs.nl
=============================================================================
  This unit will work in Delphi as well in Kylix!!!
=============================================================================
  This unit is part of both the THxServiceSeeker and THxServiceProvider class
=============================================================================
}
unit ServiceBroker_Shared;

interface

uses
{$IFDEF LINUX}
  Types, Classes,
  QStdCtrls, libc,
{$ELSE}
  Classes,
{$ENDIF}
  SysUtils, HxTcpIpcUdp;

const
  SERVICEBROKER_PORT = '12551';
  SERVICEBROKER_SERVICE = 'ServiceBroker';
  SAP_HEADER = 'Supercalifragilisticexpilidicious'; // Mary poppins ;-)

  NEW_SERVICE_ADDRESS = 5010;
  ACK_SERVICE_ADDRESS = 6010;

  SERVICE_REQ = 5011;
  SERVICE_ANS = 6011;

  REVOKE_SERVICE = 5012;
type

  THxProtocol = ( pcTcp, pcIpc, pcUdp );

  THxServiceLong = record
    sServiceName: string;
    sAddress: string;
    sPort: string;
    eProtocolType: THxProtocol;
    case boolean of
    True:
    (
      iTimeToLive: integer; // in seconds..
    );
    False:
    (
      bServAck: boolean;
    );
  end;
  PHxServiceLong = ^THxServiceLong;

  THxServiceLongList = class( TList )
  protected
    procedure Put( index: integer; pElement: PHxServiceLong );
    function  Get( index: integer ): PHxServiceLong;
    procedure Notify( ptr: Pointer; Action: TListNotification ); override;
  public
    property items[ index: integer]: PHxServiceLong read Get
             write Put; default;
    procedure Add( ptr: PHxServiceLong );
  end;

  THxServiceShort = record
    sServName: string;
    eProtocol: THxProtocol;
    iRemainingTime: integer
  end;
  PHxServiceShort = ^THxServiceShort;

  THxServiceShortList = class( TList )
  protected
    procedure Put( index: integer; pElement: PHxServiceShort );
    function  Get( index: integer ): PHxServiceShort;
    procedure Notify( ptr: Pointer; Action: TListNotification ); override;
  public
    property items[ index: integer]: PHxServiceShort read Get
             write Put; default;
    procedure Add( ptr: PHxServiceShort );
  end;

implementation


{ THxServiceLongList }

procedure THxServiceLongList.Add( ptr: PHxServiceLong );
begin
  inherited Add( ptr );
end;

function THxServiceLongList.Get( index: integer ): PHxServiceLong;
begin
  result := PHxServiceLong( inherited Get( index ));
end;

procedure THxServiceLongList.Notify( ptr: Pointer; Action: TListNotification );
begin
  if Action = lnDeleted then
    Dispose( PHxServiceLong( ptr ));
end;

procedure THxServiceLongList.Put( index: integer; pElement: PHxServiceLong );
begin
  inherited Put( index, pElement );
end;


{ THxServiceShortList }

procedure THxServiceShortList.Add( ptr: PHxServiceShort );
begin
  inherited Add( ptr );
end;

function THxServiceShortList.Get(index: integer): PHxServiceShort;
begin
  result := PHxServiceShort( inherited Get( index ));
end;

procedure THxServiceShortList.Notify(ptr: Pointer; Action: TListNotification);
begin
  if Action = lnDeleted then
    Dispose( PHxServiceShort( ptr ));
end;

procedure THxServiceShortList.Put(index: integer; pElement: PHxServiceShort );
begin
  inherited Put( index, pElement );
end;

end.
